@@ -21,10 +21,14 @@ History:
   Author: jorry.zhengyu@gmail.com    03June2020           - v2.7.11
                                                              -add NFFT initialization to estimateInitialwithRefTime
                                                              -add delimiter option to pointTrace
-  Author: w.x.chan@gmail.com         19Jan2021           - v2.7.14
+  Author: w.x.chan@gmail.com         19Jan2021           - v2.7.15
                                                              -remove Bspline2D in addBsplineFile function (bug)
                                                              -debug refTimeStep option in estimateInitialwithRefTime
                                                              -auto detect timeMapList in estimateInitialwithRefTime
+  Author: w.x.chan@gmail.com         08Jul2021           - v2.7.20
+                                                             -added fmt for pointTrace
+  Author: w.x.chan@gmail.com         15Jul2021           - v2.8.0
+                                                             -added trimesh.repair.fix_normals for pointTrace 
 
 Requirements:
     BsplineFourier
@@ -36,7 +40,7 @@ Known Bug:
     None
 All rights reserved.
 '''
-_version='2.7.14'
+_version='2.8.0'
 
 import logging
 logger = logging.getLogger(__name__)
@@ -1375,13 +1379,13 @@ class bfSolver:
             OrderedBsplinesList=range(OrderedBsplinesList)
         if self.bsplines[OrderedBsplinesList[0]].timeMap[0] is None:
             timeMapList=None
-            logger.warning('Unable to determine corresponding timemap of bsplines '+str(n)+', 'str(self.bsplines[OrderedBsplinesList[0]].timeMap)+'.')
+            logger.warning('Unable to determine corresponding timemap of bsplines '+str(n)+', '+str(self.bsplines[OrderedBsplinesList[0]].timeMap)+'.')
         else:
             timeMapList=[self.bsplines[OrderedBsplinesList[0]].timeMap[0]]
             for n in range(len(OrderedBsplinesList)):
                 if self.bsplines[OrderedBsplinesList[n]].timeMap[1] is None:
                     timeMapList=None
-                    logger.warning('Unable to determine corresponding timemap of bsplines '+str(n)+', 'str(self.bsplines[OrderedBsplinesList[n]].timeMap)+'.')
+                    logger.warning('Unable to determine corresponding timemap of bsplines '+str(n)+', '+str(self.bsplines[OrderedBsplinesList[n]].timeMap)+'.')
                     break
                 else:
                     timeMapList.append(self.bsplines[OrderedBsplinesList[n]].timeMap[1])
@@ -1437,7 +1441,11 @@ class bfSolver:
         
         self.bsFourier.regrid(refCoord,sampleCoef,tRef=tRef)
         return (refCoord,sampleCoef)
-    def pointTrace(self,stlFile,savePath,timeList=None,delimiter=' '):
+    def pointTrace(self,stlFile,savePath,timeList=None,delimiter=' ',fmt=None):
+        if fmt is None:
+            fmt='{0:.2e}'
+        elif fmt[0]!='{':
+            fmt='{0:'+fmt+'}'
         os.makedirs(savePath, exist_ok=True)
         if type(timeList)==type(None):
             timeList=10
@@ -1454,12 +1462,13 @@ class bfSolver:
             newpts=self.bsFourier.getCoordFromRef(coords)
             if stlFile[-3:]=='stl':
                 ref_mesh.vertices[:,:self.bsFourier.coef.shape[-1]]=np.array(newpts)
+                trimesh.repair.fix_normals(ref_mesh)
                 try:
-                    trimesh.io.export.export_mesh(ref_mesh,savePath+'/t{0:.2e}'.format(time)+'.stl')
+                    trimesh.io.export.export_mesh(ref_mesh,savePath+'/t'+fmt.format(time)+'.stl')
                 except:
-                    ref_mesh.export(savePath+'/t{0:.2e}'.format(time)+'.stl')
+                    ref_mesh.export(savePath+'/t'+fmt.format(time)+'.stl')
             else:
-                np.savetxt(savePath+'/t{0:.2e}'.format(time)+'.txt',np.array(newpts))
+                np.savetxt(savePath+'/t'+fmt.format(time)+'.txt',np.array(newpts))
     def estimatedStrainDetect(self,threshold=-1.,outputCoord=True):
         testShape=(np.array(self.bsFourier.coef.shape[:3])-1).astype(int)
         dXYZ=[]
